
Heading_SIZE_LIST = [
    ("font-bold text-[1.5rem] md:text-[2.125rem] lg:text-[2.125rem]", "H1"),
    ("font-bold text-[1.125rem] md:text-[1.5rem] lg:text-[1.875rem]", "H2"),
    ("font-bold text-[1.125rem] md:text-[1.25rem] lg:text-[1.5rem]", "H3"),
    ("font-bold md:text-[1.125rem] lg:text-[1.25rem]", "H4"),
    ("font-bold md:text-[1rem] lg:text-[1.125rem]", "H5"),
]

MOB_MENU_POS_LIST = [
    ('top-left', 'Top Left'),
    ('top-right', 'Top Right'),
    ('bottom-left', 'Bottom Left'),
    ('bottom-right', 'Bottom Right'),
]
ALIGNMENT_LIST = [
    ('text-left', 'Left'),
    ('text-right', 'Right'),
    ('text-center', 'Center'),
    ('text-justify', 'Justify'),
]
FONT_SIZE_LIST = [
    ('text-xs', '12 px'),
    ('text-sm', '14 px'),
    ('text-base', '16 px'),  
    ('text-lg', '18 px'),
    ('text-xl', '20 px'),
    ('text-2xl', '24 px'),
    ('text-[26px]', '26 px'),
    ('text-[28px]', '28 px'),
    ('text-3xl', '30 px'),
    ('text-[32px]', '32 px'),
    ('text-[34px]', '34 px'),
    ('text-4xl', '36 px'),
    ('text-5xl', '48 px'),
    ('text-6xl', '60 px'),
    ('text-7xl', '72 px'),
    ('text-8xl', '96 px'),
    ('text-9xl', '128 px'),
]

LINE_HEIGHT_LIST = [
    # ('leading-3', '12 px'),
    # ('leading-4', '16 px'),  # Default
    # ('leading-5', '20 px'),
    # ('leading-6', '24 px'),
    # ('leading-7', '28 px'),
    # ('leading-8', '32 px'),
    # ('leading-9', '36 px'),
    # ('leading-10', '40 px'),
    ('leading-none', 'None'),
    ('leading-tight', 'Normal'),
    ('leading-normal', 'Single'),
    ('leading-relaxed', '1.5 Line'),
    ('leading-loose', 'Double'),
]

FONT_FAMILY_LIST = [
    ('Catamaran', 'Catamaran'),
    ('Roboto', 'Roboto'),
    ('Oswald', 'Oswald'),
    ('Macklin Sans', 'Macklin Sans'),
]
STORY_THEME_POSITION = [
    ('upper-third', 'Top'),
    ('middle-third', 'Center'),
    ('bottom-third', 'Bottom')
]
MONTHS=[
    (1,1),
    (2,2),
    (3,3),
    (4,4),
    (5,5),
    (6,6),
    (7,7),
    (8,8),
    (9,9),
    (10,10),
    (11,11),
    (12,12)
]

from wagtail.blocks import *
from wagtail.images.blocks import ImageBlock
from wagtail.admin.panels import FieldPanel, MultiFieldPanel, FieldRowPanel
from wagtailmodelchooser.blocks import ModelChooserBlock
# from web.models import ExportCountry
from wagtail.documents.blocks import DocumentChooserBlock
from wagtail_color_panel.blocks import NativeColorBlock


class CarouselBlock(StructBlock):
    height = IntegerBlock(default=200, min=150, max=1200)
    width = IntegerBlock(default=400, min=350, max=2560)
    timer = IntegerBlock(default=2000, help_text="Slide time in ms")
    content = StreamBlock(
        [
            ('slide', StructBlock([
                ("image", ImageBlock(required=True)),
                ("title", CharBlock(required=False)),
                ("link", URLBlock(required=False, label="External Link")),
                ("page", PageChooserBlock(required=False, label="Internal Link")),
            ]))
        ]
    )

class ParagraphBlock(StructBlock):
    text = RichTextBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False,default="text-left")
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False,default="text-sm")
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST,required=False, label="Line Spacing",default="leading-normal")

class HeadingBlock(StructBlock):
    title = CharBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False,default="text-left")
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False,default="text-base")
    Panels = [
        MultiFieldPanel([
            FieldRowPanel([
                FieldPanel('alignment'),
                FieldPanel('size')

            ])
        ])
    ]

class HRLine(StructBlock):
    color = NativeColorBlock(required=False, default="", label="BG Color")
    double_color = StructBlock([
        ('oneColor', NativeColorBlock(
            required=False, default="", label="One Color")),
        ('twoColor', NativeColorBlock(
            required=False, default="", label="Two Color")),
    ])
    gradient = CharBlock(required=False)
    width = DecimalBlock(default=100, label="Width (px)")
    thickness = DecimalBlock(default=4, label="Thickness (px)")
    margin = StructBlock([
        ('top', DecimalBlock(
            default=0, label="Top (px)")),
        ('bottom', DecimalBlock(
            default=8, label="Bottom (px)")),
    ])

class LineBreak(StructBlock):
    line_break = CharBlock(required=False, label="Line Break", readOnly=True)

class QuoteBlock(StructBlock):
    quote = BlockQuoteBlock()
    alignment = ChoiceBlock(choices=ALIGNMENT_LIST, required=False,default="text-left")
    size = ChoiceBlock(choices=FONT_SIZE_LIST, required=False,default="text-sm")
    line_space = ChoiceBlock(choices=LINE_HEIGHT_LIST, required=False,default="leading-normal")

class CTA(StructBlock):
    title = CharBlock()
    link = URLBlock(required=False, label="URL")
    page = PageChooserBlock(required=False, label="Link to a page")
    bgColor = NativeColorBlock(
        required=False, default="#000000", label="BG Color")
    fgColor = NativeColorBlock(
        required=False, default="#FFFFFF", label="FG Color")
    hoverBgColor = NativeColorBlock(
        required=False, default="#000000", label="Hover BG Color")
    hoverFgColor = NativeColorBlock(
        required=False, default="#FFFFFF", label="Hover FG Color")
    margin = StructBlock([
        ('top', DecimalBlock(
            default=8, label="Top (px)")),
        ('bottom', DecimalBlock(
            default=10, label="Bottom (px)")),
    ])


